export function formatDateForInput(date, type, format) {
    if (type === void 0) { type = 'date'; }
    if (format === void 0) { format = 'YYYY-MM-DD'; }
    if (!date)
        return '';
    try {
        var dt = new Date(date);
        if (isNaN(dt.getTime()))
            return '';
        var year = dt.getFullYear();
        var month = "".concat(dt.getMonth() + 1).padStart(2, '0');
        var day = "".concat(dt.getDate()).padStart(2, '0');
        if (type === 'date') {
            switch (format) {
                case 'YYYY-MM-DD':
                    return "".concat(year, "-").concat(month, "-").concat(day);
                case 'DD-MM-YYYY':
                    return "".concat(day, "-").concat(month, "-").concat(year);
                default:
                    return "".concat(year, "-").concat(month, "-").concat(day);
            }
        }
        var hours = "".concat(dt.getHours()).padStart(2, '0');
        var minutes = "".concat(dt.getMinutes()).padStart(2, '0');
        switch (format) {
            case 'YYYY-MM-DD':
                return "".concat(year, "-").concat(month, "-").concat(day, "T").concat(hours, ":").concat(minutes);
            case 'DD-MM-YYYY':
                return "".concat(day, "-").concat(month, "-").concat(year, " ").concat(hours, ":").concat(minutes);
            default:
                return "".concat(year, "-").concat(month, "-").concat(day, "T").concat(hours, ":").concat(minutes);
        }
    }
    catch (_a) {
        return '';
    }
}
export function convertValueTimeParameter(value) {
    if (!value)
        return '';
    var now = new Date();
    if (value === '$$year')
        return now.getFullYear().toString();
    if (value === '$$month')
        return (now.getMonth() + 1).toString();
    if (value === '$$day')
        return now.getDate().toString();
    var regex = /^\$\$(today|now)([+-])?(\d+)?(days|months|years|weeks|hours|minutes|seconds|milliseconds)?$/;
    var match = value.match(regex);
    if (!match)
        return value;
    var base = match[1], operator = match[2], amountStr = match[3], unit = match[4];
    var offset = amountStr ? parseInt(amountStr) * (operator === '-' ? -1 : 1) : 0;
    var dt = new Date();
    if (base === 'today') {
        dt.setHours(0, 0, 0, 0);
    }
    if (unit) {
        switch (unit) {
            case 'days':
                dt.setDate(dt.getDate() + offset);
                break;
            case 'weeks':
                dt.setDate(dt.getDate() + offset * 7);
                break;
            case 'months':
                dt.setMonth(dt.getMonth() + offset);
                break;
            case 'years':
                dt.setFullYear(dt.getFullYear() + offset);
                break;
            case 'hours':
                dt.setHours(dt.getHours() + offset);
                break;
            case 'minutes':
                dt.setMinutes(dt.getMinutes() + offset);
                break;
            case 'seconds':
                dt.setSeconds(dt.getSeconds() + offset);
                break;
            case 'milliseconds':
                dt.setMilliseconds(dt.getMilliseconds() + offset);
                break;
        }
    }
    return dt.toISOString();
}
export function renderColors(arrayOption, lengthData) {
    var defaultColors = [
        '#407BFF',
        '#7489FF',
        '#A4A6FE',
        '#A1E3CB',
        '#50E7B0',
        '#A1F6FC',
        '#F1F37C',
        '#FFDB5E',
        '#F7CF95',
        '#FFB69E',
        '#FFA869',
        '#FA7DFD',
    ];
    if (!lengthData)
        return [];
    if (!arrayOption && lengthData <= 12)
        return defaultColors;
    var arrayColors = [];
    var rotatedColors = [];
    for (var i = 0; i < lengthData; i++) {
        rotatedColors.push(defaultColors[i % defaultColors.length]);
    }
    var colors = arrayOption
        .filter(function (item) { var _a; return ((_a = item === null || item === void 0 ? void 0 : item.style) === null || _a === void 0 ? void 0 : _a.bg_color) != null; })
        .map(function (item) { return item.style.bg_color; });
    arrayColors = colors.concat(rotatedColors);
    return arrayColors;
}
export var formatValue = function (value, formatString) {
    if (value == null || !formatString)
        return String(value);
    try {
        var isDateFormat = /(dd|MM|yyyy)/.test(formatString);
        if (isDateFormat) {
            var date = null;
            if (typeof value === 'string' && /^(\d{2})[-/](\d{2})[-/](\d{4})$/.test(value)) {
                var valueParts = value.split(/[/-]/);
                var formatParts = formatString.split(/[/-]/);
                var day = Number(valueParts[formatParts.indexOf('dd')]);
                var month = Number(valueParts[formatParts.indexOf('MM')]);
                var year = Number(valueParts[formatParts.indexOf('yyyy')]);
                date = new Date(year, month - 1, day);
            }
            else {
                date = new Date(value);
            }
            if (!date || isNaN(date.getTime()))
                return String(value);
            var parts_1 = {
                dd: date.getDate().toString().padStart(2, '0'),
                MM: (date.getMonth() + 1).toString().padStart(2, '0'),
                yyyy: date.getFullYear().toString(),
            };
            return formatString.replace(/dd|MM|yyyy/g, function (match) { return parts_1[match]; });
        }
        if (formatString.startsWith('#,')) {
            var num = Number(value);
            if (isNaN(num))
                return String(value);
            var decimalMatch = formatString.match(/\.0+/);
            var decimalPlaces = decimalMatch ? decimalMatch[0].length - 1 : 0;
            return num.toLocaleString('en-US', {
                minimumFractionDigits: decimalPlaces,
                maximumFractionDigits: decimalPlaces,
            });
        }
        return String(value);
    }
    catch (err) {
        console.error('formatValue error:', err);
        return String(value);
    }
};
export var isEmpty = function (value) { return value === undefined || value === null || value === ''; };
