import * as XLSX from 'xlsx';
var decodeValue = function (value) {
    if (typeof value === 'string') {
        try {
            var textarea = document.createElement('textarea');
            textarea.innerHTML = value;
            return textarea.value;
        }
        catch (_a) {
            return value;
        }
    }
    return value;
};
var changeDataWithOptionColumns = function (data, columns) {
    if (!columns || columns.length === 0)
        return data;
    var newData = data.map(function (item) {
        var newItem = {};
        columns.forEach(function (column) {
            var field = column === null || column === void 0 ? void 0 : column.field;
            var headerText = column === null || column === void 0 ? void 0 : column.header_text;
            if (field && typeof field === 'string' && headerText && item[field] !== undefined) {
                newItem[headerText] = decodeValue(item[field]);
            }
        });
        return newItem;
    });
    return newData;
};
export var downloadExcel = function (_a) {
    var data = _a.data, setupData = _a.setupData;
    try {
        var workbook = XLSX.utils.book_new();
        if (setupData === null || setupData === void 0 ? void 0 : setupData.excel_columns) {
            data = changeDataWithOptionColumns(data, setupData.excel_columns);
        }
        else if (setupData === null || setupData === void 0 ? void 0 : setupData.columns) {
            data = changeDataWithOptionColumns(data, setupData.columns);
        }
        var worksheet = XLSX.utils.json_to_sheet(data);
        XLSX.utils.book_append_sheet(workbook, worksheet, 'Sheet1');
        var now = new Date();
        var pad = function (n) { return n.toString().padStart(2, '0'); };
        var fileName = "Data.".concat(now.getFullYear()).concat(pad(now.getMonth() + 1)).concat(pad(now.getDate()), ".").concat(pad(now.getHours())).concat(pad(now.getMinutes())).concat(pad(now.getSeconds()), ".xlsx");
        var excelBuffer = XLSX.write(workbook, {
            bookType: 'xlsx',
            type: 'array',
        });
        var blob = new Blob([excelBuffer], {
            type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
        });
        return { blob: blob, fileName: fileName };
    }
    catch (error) {
        alert('Error generating Excel: ' + error);
    }
};
